@@ -2,7 +2,7 @@ from __future__ import print_function
 import numpy as np
 import mahotas as mh
 from mahotas.features import surf
-from pylab import *
+from matplotlib import pyplot as plt
 
 from os import path
 
@@ -12,15 +12,16 @@ spoints = surf.surf(f, 4, 6, 2)
 print("Nr points:", len(spoints))
 
 try:
-    import milk
+    from sklearn.cluster import KMeans
     descrs = spoints[:,5:]
     k = 5
-    values, _  =milk.kmeans(descrs, k)
+    values = KMeans(n_clusters=k).fit(descrs).labels_
     colors = np.array([(255-52*i,25+52*i,37**i % 101) for i in range(k)])
 except:
-    values = np.zeros(100)
+    values = np.zeros(100, int)
     colors = np.array([(255,0,0)])
 
 f2 = surf.show_surf(f, spoints[:100], values, colors)
-imshow(f2)
-show()
+fig,ax = plt.subplots()
+ax.imshow(f2)
+fig.show()
